@@ -1,6 +1,6 @@
 /*
     SDL_mixer:  An audio mixer library based on the SDL library
-    Copyright (C) 1997, 1998, 1999, 2000, 2001  Sam Lantinga
+    Copyright (C) 1997-2004 Sam Lantinga
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -20,7 +20,7 @@
     slouken@libsdl.org
 */
 
-/* $Id: mixer.c,v 1.47 2003/02/25 16:29:24 slouken Exp $ */
+/* $Id: mixer.c,v 1.50 2004/08/21 12:24:02 slouken Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -98,7 +98,7 @@ static void *music_data = NULL;
 const SDL_version *Mix_Linked_Version(void)
 {
 	static SDL_version linked_version;
-	MIX_VERSION(&linked_version);
+	SDL_MIXER_VERSION(&linked_version);
 	return(&linked_version);
 }
 
@@ -260,6 +260,7 @@ static void PrintFormat(char *title, SDL_AudioSpec *fmt)
 {
 	printf("%s: %d bit %s audio (%s) at %u Hz\n", title, (fmt->format&0xFF),
 			(fmt->format&0x8000) ? "signed" : "unsigned",
+			(fmt->channels > 2) ? "surround" :
 			(fmt->channels > 1) ? "stereo" : "mono", fmt->freq);
 }
 
@@ -635,6 +636,16 @@ int Mix_ReserveChannels(int num)
 	return num;
 }
 
+static int checkchunkintegral(Mix_Chunk *chunk)
+{
+	int frame_width = 1;
+
+	if ((mixer.format & 0xFF) == 16) frame_width = 2;
+	frame_width *= mixer.channels;
+	while (chunk->alen % frame_width) chunk->alen--;
+	return chunk->alen;
+}
+
 /* Play an audio chunk on a specific channel.
    If the specified channel is -1, play on the first free channel.
    'ticks' is the number of milliseconds at most to play the sample, or -1
@@ -650,6 +661,10 @@ int Mix_PlayChannelTimed(int which, Mix_Chunk *chunk, int loops, int ticks)
 		Mix_SetError("Tried to play a NULL chunk");
 		return(-1);
 	}
+	if ( !checkchunkintegral(chunk)) {
+		Mix_SetError("Tried to play a chunk with a bad frame");
+		return(-1);
+	}
 
 	/* Lock the mixer while modifying the playing channels */
 	SDL_LockAudio();
@@ -717,6 +732,10 @@ int Mix_FadeInChannelTimed(int which, Mix_Chunk *chunk, int loops, int ms, int t
 	if ( chunk == NULL ) {
 		return(-1);
 	}
+	if ( !checkchunkintegral(chunk)) {
+		Mix_SetError("Tried to play a chunk with a bad frame");
+		return(-1);
+	}
 
 	/* Lock the mixer while modifying the playing channels */
 	SDL_LockAudio();
